#ifndef LISTIMPORT_H
#define LISTIMPORT_H

namespace Shopper {
	// forward declaration
	class List;

	class ListImport {
	public:
		static List* from_plaintext(QString filename);
	};
}

#endif
